#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2008 Nacho Molina. All rights reserved.
# This program or module is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 2 of the License, or
# version 3 of the License, or (at your option) any later version. It is
# provided for educational purposes and is distributed in the hope that
# it will be useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
# the GNU General Public License for more details.

from __future__ import division
import random
import sys
import os
import tarfile
import shutil
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from modules.authorDlg import *
from modules.classes import *
from modules.const import *
from modules.about import *
from modules.wizard import *

PointSize = 10

MagicNumber = 0x70616765
FileVersion = 1

Dirty = False
home = QDir.homePath()
temp = QDir.tempPath()+"/KS"
ACTDIR=os.path.abspath(sys.path[0])

class GraphicsView(QGraphicsView):
    def __init__(self, parent=None):
        super(GraphicsView, self).__init__(parent)
        self.setDragMode(QGraphicsView.RubberBandDrag)
        self.setRenderHint(QPainter.Antialiasing)
        self.setRenderHint(QPainter.TextAntialiasing)

class MainForm(QMainWindow):
    def __init__(self, parent=None):
        super(MainForm, self).__init__(parent)
        if os.path.exists(str(temp)):pass
        else:os.mkdir(temp)
        apsize = 806,718
        self.resize(apsize[0],apsize[1])
        self.setMinimumSize(apsize[0],apsize[1])
        self.setMaximumSize(apsize[0],apsize[1])
        self.filename = QString()
        self.ultimodir = QString()
        self.z=1
        self.pixcons = []
        self.pixstatic = []
        self.recentFiles = []
        self.process = QProcess()
        self.basura = []
        MaxRecentFiles = 5
        self.n = 40
        back = None
        
# Menus y Toolbar
        self.new = QAction(QIcon('%s/images/filenew.png' %ACTDIR), self.tr('New ...'), self)
        self.new.setShortcut('Ctrl+N')
        self.new.setStatusTip(self.tr('Create a new Splash Screen.'))
        self.connect(self.new, SIGNAL('triggered()'), self.newSplash)
        
        self.save = QAction(QIcon('%s/images/filesave.png' %ACTDIR), self.tr('Save .gz'), self)
        self.save.setShortcut('Ctrl+S')
        self.save.setStatusTip(self.tr('Save compressed Splash Screen Theme file.'))
        self.connect(self.save, SIGNAL('triggered()'), self.SaveGZ)
        self.save.setEnabled(False)
                
        self.savedir = QAction(QIcon('%s/images/filesavedir.png' %ACTDIR), self.tr('Save Dir ...'), self)
        self.savedir.setStatusTip(self.tr('Save changes into a dir for manual editing.'))
        self.connect(self.savedir, SIGNAL('triggered()'), self.SaveDir)
        self.savedir.setEnabled(False)

        self.recentList = QMenu()
        self.recentList.setTitle(self.tr("Recent ..."))
        self.recentList.setIcon(QIcon('%s/images/adicon.png' %ACTDIR))
        self.recentList.clear()
        self.recentList.setEnabled(False)
          
        self.chback = QAction(QIcon('%s/images/chback.png' %ACTDIR), self.tr('Background ...'), self)
        self.chback.setShortcut('Ctrl+B')
        self.chback.setStatusTip(self.tr('Change background image of current theme.'))
        self.connect(self.chback, SIGNAL('triggered()'), self.chgBack)
        self.chback.setEnabled(False)

        self.adicon = QAction(QIcon('%s/images/adicon.png' %ACTDIR), self.tr('Icon ...'), self)
        self.adicon.setShortcut('Ctrl+I')
        self.adicon.setStatusTip(self.tr('Add a new icon to your theme.'))
        self.connect(self.adicon, SIGNAL('triggered()'), self.addPixmap)
        self.adicon.setEnabled(False)

        self.pre = QAction(QIcon('%s/images/pre.png' %ACTDIR), self.tr('Preview'), self)
        self.pre.setStatusTip(self.tr('Create a preview image for use with your theme.'))
        self.connect(self.pre, SIGNAL('triggered()'), self.preview)
        self.pre.setEnabled(False)

        self.bye = QAction(QIcon('%s/images/filequit.png' %ACTDIR), self.tr('Exit'), self)
        self.bye.setShortcut('Ctrl+Z')
        self.bye.setStatusTip(self.tr('Exit application'))
        self.connect(self.bye, SIGNAL('triggered()'), self.accept)

        self.auth = QAction(QIcon('%s/images/author.png' %ACTDIR), self.tr('Author Info ...'), self)
        self.auth.setShortcut('Ctrl+A')
        self.auth.setStatusTip(self.tr('Change basic info about the author of the theme.'))
        self.connect(self.auth, SIGNAL('triggered()'), self.chAuthor)
        self.auth.setEnabled(False)

        self.alx = QAction(QIcon('%s/images/alx.png' %ACTDIR), self.tr('Align X ...'), self)
        self.alx.setShortcut('Ctrl+X')
        self.alx.setStatusTip(self.tr('Align icons at X position of the first icon.'))
        self.connect(self.alx, SIGNAL('triggered()'), self.alignx)
        self.alx.setEnabled(False)

        self.aly = QAction(QIcon('%s/images/aly.png' %ACTDIR), self.tr('Align Y ...'), self)
        self.aly.setShortcut('Ctrl+Y')
        self.aly.setStatusTip(self.tr('Align icons at Y position of the first icon.'))
        self.connect(self.aly, SIGNAL('triggered()'), self.aligny)
        self.aly.setEnabled(False)

        self.test = QAction(QIcon('%s/images/test.png' %ACTDIR), self.tr('Test ...'), self)
        self.test.setShortcut('F5')
        self.test.setStatusTip(self.tr('Test your Splash Theme.'))
        self.connect(self.test, SIGNAL('triggered()'), self.TestSplash)
        self.test.setEnabled(False)

        self.about = QAction(QIcon('%s/images/about.png' %ACTDIR), self.tr('About ...'), self)
        self.about.setShortcut('F1')
        self.about.setStatusTip(self.tr('About KSplasherX...'))
        self.connect(self.about, SIGNAL('triggered()'), self.aboutDialog)

        self.scaleLabel = QLabel(self.tr("Scale To:  "))
        self.scaleCombo = QComboBox()
        self.scaleCombo.addItem(self.tr(""))
        self.scaleCombo.addItem(self.tr("800 x 600"))
        self.scaleCombo.addItem(self.tr("1024 x 768"))
        self.scaleCombo.addItem(self.tr("1280 x 1024"))
        self.scaleCombo.addItem(self.tr("1600 x 1200"))
        self.scaleLabel.setEnabled(False)
        self.scaleCombo.setEnabled(False)
        self.scaledCheckBox = QCheckBox(self.tr("Scaled ? "))
        self.scaledCheckBox.setChecked(False)
        self.scaledCheckBox.setEnabled(False)


        menubar = self.menuBar()
        ar = menubar.addMenu(self.tr('&File'))
        ar.addAction(self.new)
        ar.addAction(self.save)
        ar.addAction(self.savedir)
##        ar.addSeparator()
##        ar.addMenu(self.recentList)
        ar.addSeparator()
        ar.addAction(self.bye)
        
        edit = menubar.addMenu(self.tr('&Edit Theme'))
        edit.addAction(self.chback)
        edit.addAction(self.adicon)
        edit.addAction(self.pre)

        author = menubar.addMenu(self.tr('&Modify'))
        author.addAction(self.auth)
        author.addAction(self.alx)
        author.addAction(self.aly)

        about = menubar.addMenu(self.tr('&Help'))
        about.addAction(self.about)
        
        toolbar = self.addToolBar(self.tr('File'))
        toolbar.setMovable (False)
        toolbar.setIconSize(QSize(32,32))
        toolbar.setToolButtonStyle(Qt.ToolButtonTextUnderIcon)
        toolbar.addAction(self.new)
        toolbar.addAction(self.save)
        toolbar.addAction(self.savedir)
        
        toolbar2 = self.addToolBar(self.tr('Edit Theme'))
        toolbar2.setMovable (False)
        toolbar2.setIconSize(QSize(32,32))
        toolbar2.setToolButtonStyle(Qt.ToolButtonTextUnderIcon)
        toolbar2.addAction(self.chback)
        toolbar2.addSeparator()
        toolbar2.addAction(self.auth)
        toolbar2.addAction(self.alx)
        toolbar2.addAction(self.aly)
        toolbar2.addSeparator()
        toolbar2.addAction(self.test)
        toolbar2.addAction(self.bye)
        toolbar2.addSeparator()
        
# status bar + real size
        self.sizeLabel = QLabel()
        self.sizeLabel.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)
        self.status = self.statusBar()
        self.status.setSizeGripEnabled(False)
        self.status.addPermanentWidget(self.scaledCheckBox)
        self.status.addPermanentWidget(self.scaleLabel)
        self.status.addPermanentWidget(self.scaleCombo)
        
        self.connect(self.scaledCheckBox, SIGNAL("toggled(bool)"),
                self.scaleLabel, SLOT("setEnabled(bool)"))
        self.connect(self.scaleCombo, SIGNAL("activated(int)"),
                self.scalar)

        self.connect(self.scaledCheckBox, SIGNAL("toggled(bool)"),
                self.scaleCombo, SLOT("setEnabled(bool)"))
        self.connect(self.scaledCheckBox, SIGNAL("toggled(bool)"),
                self.startscaling)

        self.status.addPermanentWidget(self.sizeLabel)     
        self.status.showMessage(self.tr("Ready"), 5000)

# center prefs.

        self.view = GraphicsView()
        self.scene = QGraphicsScene(self)
        self.scene.setSceneRect(0, 0, 800, 600)       
        self.view.setCacheMode(QGraphicsView.CacheBackground)        
        self.view.setScene(self.scene)

# below we create the main form layout with the widgets

        self.setWindowTitle(self.tr("KSplasherX 2.0 beta 2"))
        self.setWindowIcon(QIcon('%s/images/ksicon.png' %ACTDIR))
        self.setCentralWidget(self.view)

    def Prueba(self):
        QMessageBox.warning(self, "KSplasherX -- PRUEBA",
                    "PRUEBA")

    def TestSplash(self):
        fname = home+"/.kde/share/apps/ksplash/Themes/"+self.data[0]
#        fname = "./NEW"
        if os.path.exists(str(fname)):
            shutil.rmtree(str(fname))
            try:self.basura.remove(fname)
            except:pass
        self.guardar()
        self.preview()
        os.mkdir(str(fname))
        self.ordenar(str(fname))
        self.basura.append(fname)
        
##        for root, dirs, files in os.walk(str(self.ruta)):
##            for name in files:
##                shutil.copy(os.path.join(str(root), str(name)),str(fname))
        
        comando = "ksplashx %s --test" %self.data[0]
        self.process.start(str(comando))

    def aboutDialog(self):
        dialog = AboutDlg(ACTDIR, parent=self)
        dialog.exec_()
        
    def reject(self):
        self.accept()


    def accept(self):
        self.offerSave()
        self.clean()
        self.close()

    def clean(self):
        if not len(self.basura)==0:
            for caca in self.basura:
                shutil.rmtree(str(caca))
        else:pass
        shutil.rmtree(str(temp))

    def offerSave(self):
        if Dirty and QMessageBox.question(self,
                            self.tr("KSplasher - Unsaved Changes"),
                            self.tr("Save unsaved changes?"),
                            QMessageBox.Yes|QMessageBox.No) == \
           QMessageBox.Yes:
            self.SaveGZ()

    def newSplash(self):
        self.B = ['']
        self.P = ['','','','']
        self.I = ['','','','','','','','']
        self.data = ['','','','','','']
        self.an=['']
        ULTIMODIR = home
        self.iconcoor = [(100,100),(150,100),(200,100),(250,100),
                         (300,100),(350,100)]
        self.piccoor = [(200,400),(300,400),(400,400),(500,400)]

        dialog = NewWizard(ACTDIR, ULTIMODIR, self.B, self.P, self.I, self.data, self.an, parent=self)
        dialog.exec_()
        self.ruta = temp+'/NEW'
        print self.ruta
        self.cargar()

        self.save.setEnabled(True)
        self.savedir.setEnabled(True)
        self.chback.setEnabled(True)
        self.auth.setEnabled(True)
        self.alx.setEnabled(True)
        self.aly.setEnabled(True)
        self.pre.setEnabled(True)
        self.test.setEnabled(True)
#        self.scaledCheckBox.setEnabled(True)

    def guardar(self):
        self.NEW=str(self.ruta)
        wait = ["kded","kcminit","ksmserver","wm","desktop"]
        items = self.pixcons
        itempics = self.pixstatic
        for i, item in enumerate(items):
            self.iconcoor[i] = int(item.x()/self.per),int(item.y()/self.per)
        for i, item in enumerate(itempics):
            self.piccoor[i] = int(item.x()/self.per),int(item.y()/self.per)

        ta=file(self.NEW+'/description.txt','w')
        ta.write('SCALE ON\n')
        if self.B!='': ta.write('IMAGE 0 0 %s\n' %os.path.basename(str(self.B[0])))
#        ta.write('SCALE OFF\n')
        if self.P!='':
            for i,p in enumerate(self.P):
                ta.write('IMAGE_REL LT %d %d LT %s\n' %(self.piccoor[i][0],
                                              self.piccoor[i][1],os.path.basename(str(p))))
        if self.I!='':
            for i,p in enumerate(self.I):
                if self.an[0]=='blink':
                    ta.write('ANIM_REL %d LT %d %d LT 30 anim%d.png 30\n' %(i+1,self.iconcoor[i][0],
                                              self.iconcoor[i][1],i+1))
                else:
                    ta.write('ANIM_REL %d LT %d %d LT 30 anim%d.png 60 1\n' %(i+1,self.iconcoor[i][0],
                                              self.iconcoor[i][1],i+1))
                ta.write('WAIT_STATE %s\n' %wait[i])
                ta.write('STOP_ANIM %d\n' %(i+1))
                ta.write('IMAGE_REL LT %d %d LT %s\n' %(self.iconcoor[i][0],
                                                        self.iconcoor[i][1],os.path.basename(str(p))))
        
        ta.write('WAIT_STATE ready\n')

        th=file(self.NEW+'/Theme.rc','w')
        for i in RC_ORD:
            if i=='[KSplash Theme':
                th.write(i+': '+self.data[0]+']\n')# Generamos el archivo .RC
            else: th.write(i+' = '+self.data[Datos[i]]+'\n')# Generamos el archivo .RC

        
    def cargar(self):
        self.pixcons = []
        self.pixstatic = []
        self.iconcoor = [(100,100),(150,100),(200,100),(250,100),
                         (300,100),(350,100)]
        self.piccoor = [(200,400),(300,400),(400,400),(500,400)]
        items = self.scene.items()
        while items:
            item = items.pop()
            self.scene.removeItem(item)
            del item

        if os.path.exists(self.B[0]):
            back = QPixmap(self.B[0])
            self.ancho,self.alto = back.width(),back.height()
            self.per = 800/back.width()
            self.sizeLabel.setText("%d x %d" % (back.width(), back.height()))
            self.nombredir = ("%dx%d" % (back.width(), back.height()))
        else:
            QMessageBox.warning(self, self.tr("KSplasherX - Invalid Background"),
                    self.tr("Your theme doesn't have a background image"))
            back = QPixmap()
            self.per = 1

#Llenamos la pantalla
        self.view.setBackgroundBrush(QBrush(QPixmap.scaledToWidth(back,800)))
        
        j = 0
        while j in range(len(self.P)):
            pix = QPixmap(self.P[j])
            wid = pix.width()*self.per
            x,y = self.piccoor[j][0],self.piccoor[j][1]
            self.createPixmapItem(QPixmap.scaledToWidth(pix,wid),
                                    self.view.mapToScene(QPoint(x,y)),'static')
##            self.createPixmapItem(pix,self.view.mapToScene(QPoint(x,y)),'static')
            j = j+1

        j = 0
        while j in range(len(self.I)):
            pix = QPixmap(self.I[j])
            wid = pix.width()*self.per
            x,y = self.iconcoor[j][0],self.iconcoor[j][1]
            self.createPixmapItem(QPixmap.scaledToWidth(pix,wid),
                                    self.view.mapToScene(QPoint(x,y)),'icon')
##            self.createPixmapItem(pix,self.view.mapToScene(QPoint(x,y)),'icon')
            j = j+1
        self.back = back

    def startscaling(self):
        if self.scaledCheckBox.isChecked()==True:
            items = self.pixcons
            itempics = self.pixstatic
            for i, item in enumerate(items):
                self.iconcoor[i] = int(item.x()),int(item.y())
            for i, item in enumerate(itempics):
                self.piccoor[i] = int(item.x()),int(item.y())
        else:
            self.scaleCombo.setCurrentIndex(0)
            self.cargar()
        
    def scalar(self):
            
        items = self.scene.items()

        while items:
            item = items.pop()
            self.scene.removeItem(item)
            del item

        scalarSize = self.scaleCombo.currentText()
        if scalarSize == '800 x 600':
            self.perscaled=800/800
        elif scalarSize == '1024 x 768':
            self.perscaled=800/1024
        elif scalarSize == '1280 x 1024':
            self.perscaled=800/1280
        elif scalarSize == '1600 x 1200':
            self.perscaled=800/1600
        else: self.perscaled=800/self.back.width()

        j = 0
        while j in range(len(self.P)):
            pix = QPixmap(self.P[j])
            wid = pix.width()*self.perscaled
            x,y = (((self.piccoor[j][0]*self.perscaled/self.per)+self.piccoor[j][0])/2,
                   ((self.piccoor[j][1]*self.perscaled/self.per)+self.piccoor[j][1])/2)
            self.createPixmapItem(QPixmap.scaledToWidth(pix,wid),
                                    self.view.mapToScene(QPoint(x,y)),'static')
            j = j+1

        j = 0
        while j in range(len(self.I)):
            pix = QPixmap(self.I[j])
            wid = pix.width()*self.perscaled
            x,y = (self.iconcoor[j][0]*self.perscaled/self.per,
                   ((self.iconcoor[j][1]*self.perscaled/self.per)+self.iconcoor[j][1])/2)
            self.createPixmapItem(QPixmap.scaledToWidth(pix,wid),
                                    self.view.mapToScene(QPoint(x,y)),'icon')
            j = j+1

    def chAuthor(self):
        dialog = AuthorDlg(self.data, ACTDIR, parent=self)
        dialog.exec_()

    def addPixmap(self):
        path = QFileInfo(self.filename).path() \
            if not self.filename.isEmpty() else "."
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        self.createPixmapItem(QPixmap(fname), self.position())

        global Dirty
        Dirty = True

    def chgBack(self):
        path = QFileInfo(self.filename).path() \
            if not self.filename.isEmpty() else "."
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Background"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        img = QImage(fname)
        fname = os.path.join(str(self.ruta),'background.png')
##        img2 = img.scaled(self.ancho,self.alto)
        img.save(fname)
        back=QPixmap(fname)
        self.view.setBackgroundBrush(QBrush(QPixmap.scaledToWidth(back,800)))
        self.sizeLabel.setText("%d x %d" % (back.width(), back.height()))
        self.nombredir = ("%dx%d" % (back.width(), back.height()))

        self.B[0]=str(fname)
        self.cargar()
        global Dirty
        Dirty = True

    def createPixmapItem(self, pixmap, position, tipo, matrix=QMatrix()):
        item = QGraphicsPixmapItem(pixmap)
        if self.scaledCheckBox.isChecked()==True:None
        else:item.setFlags(QGraphicsItem.ItemIsSelectable|
                          QGraphicsItem.ItemIsMovable)
        item.setPos(position)
        item.setMatrix(matrix)
        self.scene.clearSelection()
        self.scene.addItem(item)        
        item.setSelected(True)
        if tipo=='static':
            self.pixstatic.append(item)
        else:
            self.pixcons.append(item)
            item.setZValue(self.z)
            self.z=self.z+1
        
        global Dirty
        Dirty = True        

    def selectedItem(self):
        items = self.scene.selectedItems()
        if len(items) == 1:
            return items[0]
        return None

    def alignx(self):
        self.setAlignment(Qt.AlignBottom)
        
    def aligny(self):
        self.setAlignment(Qt.AlignLeft)

    def setAlignment(self, alignment):
        items = self.pixcons
        if len(items) <= 1:
            return
        index = 0
        rect = items[index].sceneBoundingRect()
        # Find how much the other items must move by
        dialog = QInputDialog.getInteger(self, self.tr("Align Spacing"),
                                    self.tr("Spacing (in pixels):"), self.n, 0, 100, 1)
        self.n = dialog[0]
        n = self.n
        for i, item in enumerate(items):
            if i == index:
                item.setSelected(True)
                continue
            itemrect = item.sceneBoundingRect()
            xOffset = yOffset = 0
            if alignment == Qt.AlignLeft:
                xOffset = rect.x() - itemrect.x()
                yOffset = rect.y() - itemrect.y() + n
##            elif alignment == Qt.AlignRight:
##                xOffset = (rect.x() + rect.width()) - \
##                          (itemrect.x() + itemrect.width())
##            elif alignment == Qt.AlignTop:
##                yOffset = rect.y() - itemrect.y()
            elif alignment == Qt.AlignBottom:
                xOffset = rect.x() - itemrect.x() + n
                yOffset = (rect.y() + rect.height()) - \
                          (itemrect.y() + itemrect.height())
            item.moveBy(xOffset, yOffset)
            item.setSelected(True)
            n = n + self.n
        global Dirty
        Dirty = True

##    def delete(self):
##        items = self.scene.selectedItems()
##        if len(items) and QMessageBox.question(self,
##                "KSplasher - Delete",
##                "Delete %d item%s?" % (len(items),
##                "s" if len(items) != 1 else ""),
##                QMessageBox.Yes|QMessageBox.No) == QMessageBox.Yes:
##            while items:
##                item = items.pop()
##                self.scene.removeItem(item)
##                del item
##            global Dirty
##            Dirty = True

    def preview(self):
        img=QImage(512,384,QImage.Format_RGB32)
        self.scene.clearSelection()
        painter=QPainter(img)
        self.view.render(painter)
        painter.end()
        img.save(os.path.join(str(self.ruta),'Preview.png'))

    def SaveDir(self):
        self.guardar()
        self.preview()
        path = home
        fname = QFileDialog.getExistingDirectory(self,
                            self.tr("KSplasher - Save Directory"), path, QFileDialog.ShowDirsOnly
                                                 | QFileDialog.DontResolveSymlinks)

        if fname.isEmpty(): return
        elif fname == self.ruta: pass
        else:
            self.ordenar(fname)
        self.status.showMessage(str(self.tr('Theme created in directory "%s".'))
                                %os.path.basename(str(fname)), 5000)

    def ordenar(self,fname):
        dire=('%s/%s' %(fname,self.nombredir))
        os.mkdir(dire)
        for root, dirs, files in os.walk(str(self.ruta)):
            for name in files:
                if name=='Preview.png' or name=='Theme.rc':
                    shutil.copy(os.path.join(str(root), str(name)),str(fname))
                else:
                    shutil.copy(os.path.join(str(root), str(name)),str(dire))
        
            
    def SaveAsGZ(self):
        self.filename.clear()
        self.SaveGZ()
        
    def SaveGZ(self):
        self.guardar()
        self.preview()
        os.mkdir(temp+'/'+self.data[0])
        self.ordenar(temp+'/'+self.data[0])
        if self.filename.isEmpty():
            path = home
            fname = QFileDialog.getSaveFileName(self,
                                self.tr("KSplasher - Save As"), path,
                                self.tr("Compressed Files (*.tar.gz)"))
            if fname.isEmpty(): return
            else: self.filename = fname+'.tar.gz'
        tar = tarfile.open(str(self.filename),"w:gz")
        tar.add(str(temp+'/'+self.data[0]),self.data[0])
        tar.close()
        self.status.showMessage(str(self.tr('File "%s" saved.'))
                                %os.path.basename(str(self.filename)), 5000)
        
        global Dirty
        Dirty = False

def setupTranslator(app):
    translator = QTranslator(app)
    lng = str(QLocale.system().name()).split("_")[0]
    translator.load("%s/lang/%s.qm" %(ACTDIR,str(lng)))
    app.installTranslator(translator)


class Inicio(QApplication):
    """Splash + Main Window"""
    def __init__(self,args=None):

        QApplication.__init__(self,args)
        setupTranslator(self)
        pixmap = QPixmap("images/logo.png",'png')
        self.splash = QSplashScreen(pixmap,Qt.WindowStaysOnTopHint)
        self.splash.show()
        QTimer.singleShot(2000,self.splash,SLOT("hide()"))
        self.mywindow = MainForm()
        self.mywindow.show()
        self.exec_()

if __name__ == "__main__":
#    app = QApplication(sys.argv)
#    setupTranslator(app)
#    form = MainForm()
#    form.show()
#    app.exec_()
    app = Inicio(sys.argv)

    

