#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys,os,shutil
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from const import *
from filters import *

home = QDir.homePath()
temp = QDir.tempPath()+"/KS"

class SimpleWizard(QDialog):
    def __init__(self, parent=None):
        QDialog.__init__(self, parent)

        self.history = []
        self.numPages = 0
       
        
        self.cancelButton = QPushButton(self.tr("Cancel"))
        self.backButton = QPushButton(self.tr("< &Back"))
        self.nextButton = QPushButton(self.tr("Next >"))
        self.finishButton = QPushButton(self.tr("&Finish"))
    
        self.connect(self.cancelButton, SIGNAL("clicked()"), self, SLOT("reject()"))
        self.connect(self.backButton, SIGNAL("clicked()"), self.backButtonClicked)
        self.connect(self.nextButton, SIGNAL("clicked()"), self.nextButtonClicked)
        self.connect(self.finishButton, SIGNAL("clicked()"), self, SLOT("accept()"))
    
        buttonLayout = QHBoxLayout()
        buttonLayout.addStretch(1)
        buttonLayout.addWidget(self.cancelButton)
        buttonLayout.addWidget(self.backButton)
        buttonLayout.addWidget(self.nextButton)
        buttonLayout.addWidget(self.finishButton)
    
        self.mainLayout = QVBoxLayout()
        self.mainLayout.addLayout(buttonLayout)
        self.setLayout(self.mainLayout)

    def setButtonEnabled(self, enable):
        if len(self.history) == self.numPages:
            self.finishButton.setEnabled(enable)
        else:
            self.nextButton.setEnabled(enable)

    def setNumPages(self, n):
        self.numPages = n
        self.history.append(self.createPage(0))
        self.switchPage(0)

    def backButtonClicked(self):
        self.nextButton.setEnabled(True)
        self.finishButton.setEnabled(True)
    
        oldPage = self.history.pop()
        self.switchPage(oldPage)
        del oldPage

    def nextButtonClicked(self):
        self.nextButton.setEnabled(True)
        self.finishButton.setEnabled(len(self.history) == self.numPages - 1)
    
        oldPage = self.history[-1]
        self.history.append(self.createPage(len(self.history)))
        self.switchPage(oldPage)

    def switchPage(self, oldPage):
        if oldPage:
            oldPage.hide()
            self.mainLayout.removeWidget(oldPage)

        newPage = self.history[-1]
        self.mainLayout.insertWidget(0, newPage)
        newPage.show()
        newPage.setFocus()
    
        self.backButton.setEnabled(len(self.history) != 1)
        if len(self.history) == self.numPages:
            self.nextButton.setEnabled(False)
            self.finishButton.setDefault(True)
        else:
            self.nextButton.setDefault(True)
            self.finishButton.setEnabled(False)

        self.setWindowTitle(self.tr("New Splash Wizard - Step %1 of %2")
                                    .arg(len(self.history)).arg(self.numPages))
                       

class NewWizard(SimpleWizard):
    def __init__(self, ACTDIR, ULTIMODIR, bb, pp, ii, data, an, parent=None):
        SimpleWizard.__init__(self, parent)
        self.ACT = ACTDIR
        self.ULT = ULTIMODIR
        self.resize(580,450)
        self.setNumPages(6)
        self.data = data
        self.b = bb
        self.i = ii
        self.p = pp
        self.an = an
        
    def createPage(self, index):
        if index == 0:
            self.zeroPage = welcomePage(self, self.ACT)
            return self.zeroPage
        elif index == 1:
            self.firstPage = backPage(self, self.ACT, self.ULT)
            return self.firstPage
        elif index == 2:
            self.secondPage = picsPage(self, self.ACT, self.firstPage.ultimodir)
            return self.secondPage
        elif index == 3:
            self.thirdPage = iconPage(self, self.ACT, self.secondPage.ultimodir)
            return self.thirdPage
        elif index == 4:
            self.fourthPage = authorPage(self, self.ACT)
            return self.fourthPage
        elif index == 5:
            self.fifthPage = finishPage(self, self.ACT)
            return self.fifthPage

        return 0

    def accept(self):
        self.NEW=str(temp+'/NEW')
        if os.path.exists(self.NEW):pass
        else:os.mkdir(self.NEW)

## background
        self.b[0] = self.firstPage.back
        fname=self.b[0]
        if fname!='':
            if os.path.splitext(str(fname))[1]!='.png':
                img = QImage(fname)
                fname = os.path.join(self.NEW,'background.png')
                img.save(fname)
                self.b[0] = fname
            else: 
                shutil.copy(self.b[0],self.NEW)
        else:pass
       	print self.b[0]
## static pics
        self.p[0]=self.secondPage.pic1
        self.p[1]=self.secondPage.pic2
        self.p[2]=self.secondPage.pic3
        self.p[3]=self.secondPage.pic4
        largo = len(self.p)
        for r in range(largo):
            try:self.p.remove('')
            except:pass
        if self.p!=[]:
            for num,n in enumerate(self.p):
                if os.path.splitext(str(n))[1]!='.png':
                    img = QImage(n)
                    n = os.path.splitext(str(n))[0]+'.png'
                    img.save(n)
                else:pass
                shutil.move(n,self.NEW)
                self.p[num]=os.path.join(self.NEW,os.path.basename(n))
                print self.p[num]
        else:pass

## icons
        self.i[0]=self.thirdPage.newicons[0]
        self.i[1]=self.thirdPage.newicons[1]
        self.i[2]=self.thirdPage.newicons[2]
        self.i[3]=self.thirdPage.newicons[3]
        self.i[4]=self.thirdPage.newicons[4]
        self.i[5]=self.thirdPage.newicons[5]
        self.i[6]=self.thirdPage.newicons[6]
        self.i[7]=self.thirdPage.newicons[7]
        largo = len(self.i)
        for r in range(largo):
            try:self.i.remove('')
            except:pass
        if self.i!=[]:
            if self.thirdPage.animBlink.isChecked():
                self.an[0] = 'blink'
                for num,n in enumerate(self.i):
                    blink(n,'%s/anim%s.png' %(self.NEW,num+1))
                    shutil.copy(n,self.NEW)
            else:
                self.an[0] = 'fadeon'
                for num,n in enumerate(self.i):
                    fadeon(n,'%s/anim%s.png' %(self.NEW,num+1))
                    shutil.copy(n,self.NEW)
        else:pass
        
## Author Data
        self.crearTheme()
        
        QDialog.accept(self)

    def crearTheme(self):
#        self.data = ['','','','','','']
        self.data[0]=str(self.fourthPage.nameEdit.text())
        self.data[1]=str(self.fourthPage.desEdit.text())
        self.data[2]=str(self.fourthPage.verEdit.text())
        if str(self.fourthPage.autEdit.text())!='' and str(self.fourthPage.emEdit.text())!='':
            self.data[3]=str(self.fourthPage.autEdit.text()+" <"+self.fourthPage.emEdit.text()+">")
        else:
            self.data[3]=str(self.fourthPage.autEdit.text())
        self.data[4]=str(self.fourthPage.pageEdit.text())
        self.data[5]=str('KSplashX')
        

class welcomePage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)
        self.topLabel = QLabel(self.tr("<center><b>Welcome to the<br>"
                                       "New Splash Screen WIzard</b>"
                                             "<p>We will ask you a few questions and<br> "
                                             "then you will have your new Splash Screen.</center>"))
        self.topLabel.setWordWrap(False)
        self.topLabel.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/ksicon.png" %ACTDIR))
        
        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addWidget(self.topLabel)

        self.setLayout(horizontalLayout)
        
class finishPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)

        self.topLabel = QLabel(self.tr("<center><b>Wizard Complete</b>"
                                             "<p>All the needed information has been collected<br> "
                                             "you can now press 'Finish' and start editing.</center>"))
        self.topLabel.setWordWrap(False)
        self.topLabel.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/okbig.png" %ACTDIR))

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addWidget(self.topLabel)

        self.setLayout(horizontalLayout)

        

class backPage(QWidget):
    def __init__(self, parent, ACTDIR, ULTIMODIR):
        QWidget.__init__(self, parent)
        self.ultimodir = ULTIMODIR
        self.topLabel = QLabel(self.tr("<center><b>Background Image</b></center>"))
        self.topLabel.setWordWrap(False)
        self.back=''
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/back.png" %ACTDIR))
        iconBtn = QPushButton(self.tr("Load ..."))
        self.connect(iconBtn, SIGNAL('clicked()'), self.setBack)
        
        self.imgLabel = QLabel(self)
        self.imgLabel.setPixmap(QPixmap.scaled(QPixmap("%s/images/blank.png" %ACTDIR), 320, 240))
#        self.scaledCheckBox = QCheckBox(self.tr("Scaled ?"))
#        self.scaledCheckBox.setChecked(True)
        self.imgLabel.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)

        rightLayout = QGridLayout()
        rightLayout.addWidget(self.topLabel, 0, 1, 1, 2)
        rightLayout.addWidget(self.imgLabel, 1, 0, 1, 4)
        rightLayout.addWidget(iconBtn, 2, 0, 1, 2)
#        rightLayout.addWidget(self.scaledCheckBox, 2, 3, 1, 2)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)

    def setBack(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Set Background Image"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.imgLabel.setPixmap(QPixmap.scaled(QPixmap(str(fname)), 320, 240))
        self.back=str(fname)

class picsPage(QWidget):
    def __init__(self, parent, ACTDIR, ULTIMODIR):
        QWidget.__init__(self, parent)
        self.ultimodir = ULTIMODIR
        self.topLabel = QLabel(self.tr("<center><b>Static Pics</b></center>"))
        self.topLabel.setWordWrap(False)        
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/back.png" %ACTDIR))
        
        iconBtn1 = QPushButton(self.tr("Load ..."))
        self.connect(iconBtn1, SIGNAL('clicked()'), self.setPic1)
        self.pic1=''
        self.imgLabel1 = QLabel(self)
        self.imgLabel1.setPixmap(QPixmap.scaled(QPixmap("%s/images/blank.png" %ACTDIR), 160, 120))
        self.imgLabel1.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)

        iconBtn2 = QPushButton(self.tr("Load ..."))
        self.connect(iconBtn2, SIGNAL('clicked()'), self.setPic2)
        self.pic2=''
        self.imgLabel2 = QLabel(self)
        self.imgLabel2.setPixmap(QPixmap.scaled(QPixmap("%s/images/blank.png" %ACTDIR), 160, 120))
        self.imgLabel2.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)

        iconBtn3 = QPushButton(self.tr("Load ..."))
        self.connect(iconBtn3, SIGNAL('clicked()'), self.setPic3)
        self.pic3=''
        self.imgLabel3 = QLabel(self)
        self.imgLabel3.setPixmap(QPixmap.scaled(QPixmap("%s/images/blank.png" %ACTDIR), 160, 120))
        self.imgLabel3.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)

        iconBtn4 = QPushButton(self.tr("Load ..."))
        self.connect(iconBtn4, SIGNAL('clicked()'), self.setPic4)
        self.pic4=''
        self.imgLabel4 = QLabel(self)
        self.imgLabel4.setPixmap(QPixmap.scaled(QPixmap("%s/images/blank.png" %ACTDIR), 160, 120))
        self.imgLabel4.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)

#        self.scaledCheckBox = QCheckBox(self.tr("Scaled Pics ?"))
#        self.scaledCheckBox.setChecked(True)
        
        rightLayout = QGridLayout()
        rightLayout.addWidget(self.topLabel, 0, 1, 1, 2)
        rightLayout.addWidget(self.imgLabel1, 1, 0, 1, 2)
        rightLayout.addWidget(iconBtn1, 2, 0, 1, 2)
        rightLayout.addWidget(self.imgLabel2, 1, 2, 1, 2)
        rightLayout.addWidget(iconBtn2, 2, 2, 1, 2)
        rightLayout.addWidget(self.imgLabel3, 3, 0, 1, 2)
        rightLayout.addWidget(iconBtn3, 4, 0, 1, 2)
        rightLayout.addWidget(self.imgLabel4, 3, 2, 1, 2)
        rightLayout.addWidget(iconBtn4, 4, 2, 1, 2)
        
#        rightLayout.addWidget(self.scaledCheckBox, 5, 3, 1, 2)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)

    def setPic1(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Set Background Image"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.imgLabel1.setPixmap(QPixmap.scaled(QPixmap(str(fname)), 160, 120))
        self.pic1=str(fname)

    def setPic2(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Set Background Image"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.imgLabel2.setPixmap(QPixmap.scaled(QPixmap(str(fname)), 160, 120))
        self.pic2=str(fname)

    def setPic3(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Set Background Image"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.imgLabel3.setPixmap(QPixmap.scaled(QPixmap(str(fname)), 160, 120))
        self.pic3=str(fname)

    def setPic4(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Set Background Image"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.imgLabel4.setPixmap(QPixmap.scaled(QPixmap(str(fname)), 160, 120))
        self.pic4=str(fname)
        
class iconPage(QWidget):
    def __init__(self, parent, ACTDIR, ULTIMODIR):
        QWidget.__init__(self, parent)
        self.ultimodir = ULTIMODIR
        self.topLabel = QLabel(self.tr("<center><b>Icons</b>"
                                             "<p>Set the desired icon images "
                                             "for your new Splash Screen Theme.</center>"))
        self.topLabel.setWordWrap(False)

        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/iconbig.png" %ACTDIR))
        movieLabel = QLabel(self)
        movie = QMovie ("%s/images/blink.gif" %ACTDIR)
        movieLabel.setMovie(movie)
        movie.start()
#        self.scaledCheckBox = QCheckBox(self.tr("Scaled ?"))
#        self.scaledCheckBox.setChecked(True)

        self.newicons=["","","","","","","",""]
        self.icon1 = QToolButton()
#        self.icon1.setIcon(QIcon("%s/images/1.png" %ACTDIR))
        self.icon1.setIconSize(QSize(64, 64))
        self.connect(self.icon1, SIGNAL('clicked()'), self.chgIcon1)
        self.icon2 = QToolButton()
#        self.icon2.setIcon(QIcon("%s/images/2.png" %ACTDIR))
        self.icon2.setIconSize(QSize(64, 64))
        self.connect(self.icon2, SIGNAL('clicked()'), self.chgIcon2)
        self.icon3 = QToolButton()
#        self.icon3.setIcon(QIcon("%s/images/3.png" %ACTDIR))
        self.icon3.setIconSize(QSize(64, 64))
        self.connect(self.icon3, SIGNAL('clicked()'), self.chgIcon3)
        self.icon4 = QToolButton()
#        self.icon4.setIcon(QIcon("%s/images/4.png" %ACTDIR))
        self.icon4.setIconSize(QSize(64, 64))
        self.connect(self.icon4, SIGNAL('clicked()'), self.chgIcon4)
        self.icon5 = QToolButton()
#        self.icon5.setIcon(QIcon("%s/images/5.png" %ACTDIR))
        self.icon5.setIconSize(QSize(64, 64))
        self.connect(self.icon5, SIGNAL('clicked()'), self.chgIcon5)

        authorLayout = QGridLayout()
        authorLayout.addWidget(self.icon1, 0, 0)
        authorLayout.addWidget(self.icon2, 0, 1)
        authorLayout.addWidget(self.icon3, 0, 2)
        authorLayout.addWidget(self.icon4, 1, 0)
        authorLayout.addWidget(self.icon5, 1, 1)

        authorGroup = QGroupBox(self.tr("Icons"))
        authorGroup.setLayout(authorLayout)

        self.animBlink = QRadioButton(self.tr("Blinking Icons"))
        self.animBlink.setChecked(True)
        self.animBlur = QRadioButton(self.tr("Fading On Icons"))
        animLayout = QHBoxLayout()
        animLayout.addWidget(self.animBlink)
        animLayout.addWidget(self.animBlur)
        animGroup = QGroupBox(self.tr("Animation Type"))
        animGroup.setLayout(animLayout)

        
        rightLayout = QGridLayout()
        rightLayout.addWidget(self.topLabel, 0, 0, 1, -1)
        rightLayout.addWidget(QLabel(" "))
        rightLayout.addWidget(authorGroup, 1, 0, 1, 4)
#        rightLayout.addWidget(self.scaledCheckBox, 2, 2, 1, 2)
        rightLayout.addWidget(animGroup, 3, 0, 1, 4)
        rightLayout.addWidget(movieLabel,4,0,1,2)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)

    def chgIcon1(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[0]=str(fname)
        self.icon1.setIcon(QIcon(fname))
        
    def chgIcon2(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[1]=str(fname)
        self.icon2.setIcon(QIcon(fname))
        
    def chgIcon3(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[2]=str(fname)
        self.icon3.setIcon(QIcon(fname))
        
    def chgIcon4(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[3]=str(fname)
        self.icon4.setIcon(QIcon(fname))
        
    def chgIcon5(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[4]=str(fname)
        self.icon5.setIcon(QIcon(fname))
               
class authorPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)
        
        self.topLabel = QLabel(self.tr("<center><b>Author Information</b>"
                                             "<p>Set up theme name, description "
                                             "and personal author information.</center>"))
        self.topLabel.setWordWrap(False)
        
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/authorbig.png" %ACTDIR))
        
        nameLabel = QLabel(self.tr("Theme Name:"))
        self.nameEdit = QLineEdit()
        desLabel = QLabel(self.tr("Description:"))
        self.desEdit = QLineEdit()
        verLabel = QLabel(self.tr("Version:"))
        self.verEdit = QLineEdit()
        autLabel = QLabel(self.tr("Author:"))
        self.autEdit = QLineEdit()       
        emLabel = QLabel(self.tr("E-mail:"))
        self.emEdit = QLineEdit()
        pageLabel = QLabel(self.tr("Homepage:"))
        self.pageEdit = QLineEdit()

        authorLayout = QGridLayout()
        authorLayout.addWidget(nameLabel, 0, 0)
        authorLayout.addWidget(self.nameEdit, 0, 1, 1, 10)
        authorLayout.addWidget(desLabel, 1, 0)
        authorLayout.addWidget(self.desEdit, 1, 1, 1, 10)
        authorLayout.addWidget(verLabel, 2, 0)
        authorLayout.addWidget(self.verEdit, 2, 1, 1, 2)
        authorLayout.addWidget(autLabel, 3, 0)
        authorLayout.addWidget(self.autEdit, 3, 1, 1, 10)
        authorLayout.addWidget(emLabel, 4, 0)
        authorLayout.addWidget(self.emEdit, 4, 1, 1, 10)
        authorLayout.addWidget(pageLabel, 5, 0)
        authorLayout.addWidget(self.pageEdit, 5, 1, 1, 10)

        authorGroup = QGroupBox(self.tr("Author Information"))
        authorGroup.setLayout(authorLayout)

        rightLayout = QVBoxLayout()
        rightLayout.addWidget(self.topLabel)
        rightLayout.addWidget(QLabel(""))
        rightLayout.addWidget(authorGroup)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)
        

if __name__ == '__main__':
    app = QApplication(sys.argv)
    wizard = NewWizard("..")
    wizard.exec_()
